==> tine20-allinone_2019.12.5.tar.bz2: Setup/js/Setup-lang-sq-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: sq\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Backend"
: "Fundori"

, "Standard IMAP"
: "IMAP standart"

, "Standard SMTP"
: "SMPT standarte"

, "Imap"
: "Imap"

, "Hostname"
: "Emri i Pritësit(Host)"

, "Username"
: "Emri Përdoruesit"

, "Password"
: "Fjalëkalimi"

, "Port"
: "Porta"

, "Secure Connection"
: "Lidhje e sigurtë"

, "None"
: "Asnjë"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Përdor llogarinë e sistemit"

, "No"
: "Jo"

, "Yes"
: "Po"

, "Append domain to login name"
: "Bashkangjit domain me emrin e hyrjes"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Administrator Cyrus"

, "Cyrus Admin Password"
: "Fjalëkalimi i administratorit Cyrus"

, "Use proxy auth"
: "Përdor autentifikim proxy"

, "Smtp"
: "Smtp"

, "Authentication"
: "Autentifikim"

, "Login"
: "Hyrje"

, "Plain"
: "E thjeshtë"

, "Primary Domain"
: "Domain parësor"

, "Secondary Domains (comma separated)"
: "Domain dytësor (e ndare me presje)"

, "Notifications service address"
: "Adresa e shërbimit të njoftimeve"

, "Notification Username"
: "Emër përdoruesi i njoftuesit"

, "Notification Password"
: "Fjalëkalimi i njoftuesit"

, "Notifications local client (hostname or IP address)"
: "Klienti lokal i njoftimeve ( emri pritesit(host) ose adresa IP)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "Emri Pritësit(host) MySql"

, "MySql Database"
: "Databaza MySql"

, "MySql User"
: "Përdoruesi MySql"

, "MySql Password"
: "Fjalëkalimi MySql"

, "MySql Port"
: "Porta MySql"

, "User or UID"
: "Përdorues ose UID"

, "Group or GID"
: "Grup ose GID"

, "Home Template"
: "Shablloni kryesor"

, "Password Scheme"
: "Skema e Fjalëkalimit"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLAIN"

, "I have read the license agreement and accept it"
: "Unë e kam lexuar marrveshjen e licensave dhe e kam pranuar atë"

, "License Agreement"
: "Marveshje Licensash"

, "I have read the privacy agreement and accept it"
: "Unë e kam lexuar marrveshjen e fshehtësive dhe e kam pranuar atë"

, "Privacy Agreement"
: "Marrveshje e Fshehtësive"

, "Accept Terms and Conditions"
: "Prano Kushtet dhe Konditat"

, "Performing Environment Checks..."
: "Duke kryer kontrollet e ambientit..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "Nuk u gjet ndonje {0}. Ju lutem provoni të ndryshoni kërkesat e fitrave tuaj, mundësite e shfaqesose {1} ku kërkoni"

, "Check"
: "Kontrollo"

, "Result"
: "Rezultati"

, "Error"
: "Gabim"

, "Run setup tests"
: "Kryej teste konfigurimi"

, "Ignore setup tests"
: "Injoro testet e konfigurimit"

, "Install application"
: "Instalo aplikacionin"

, "File"
: "Skedar"

, "Setup Authentication"
: "Autentifikimi i Konfigurimit"

, "Database"
: "Databaza"

, "User"
: "Përdorues"

, "Prefix"
: "Prefiks"

, "Logging"
: "Hyrje"

, "Filename"
: "Emri i Skedarit"

, "Priority"
: "Prioriteti"

, "Caching"
: "Duke Fshehur(caching)"

, "Lifetime (seconds)"
: "Kohzgjatja (seconda)"

, "Path"
: "Rruga"

, "Queue"
: "Rradhë"

, "Session"
: "Seksion"

, "Temporary files"
: "Skedarë të përkohshëm"

, "Temporary Files Path"
: "Rrugë e përkohshme e skedarëve"

, "Filestore directory"
: "Vendruajtja e skedarëve"

, "Filestore Path"
: "Rruga e vendruajtjes së skedarëve"

, "Addressbook Map panel"
: "Paneli i hartës së Bllokut të adresave"

, "Map panel"
: "Paneli hartës"

, "disabled"
: "ç'aktivizuar"

, "enabled"
: "aktivizuar"

, "Config file is not writable"
: "Skedari i konfigurimit nuk është i shkruajtshëm "

, "Save config"
: "Ruaj konfigurimin"

, "Download config file"
: "Shkarko skedarin e konfigurimit"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Terms and Conditions"
: "Kushtet dhe Konditat"

, "Setup Checks"
: "Kontrolle Konfigurimi"

, "Config Manager"
: "Menaxhuesi i Konfigurimeve"

, "Authentication/Accounts"
: "Autentifikimi/Llogaritë"

, "Email"
: "E-Postë"

, "Application Manager"
: "Menaxheri i Aplikacioneve"

, "Delete all existing users and groups"
: "Fshij të gjithë Grupet dhe Përdoruesit"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Ndryshimi nga SQL në LDAP do të fshijë të gjitha Logaritë e Përdoruesëve, Grupet, dhe RoletDoni vërtetë të ndryshoni arkivën fundore të përdoruesve në LDAP?"

, "TLS client certificate"
: "Certifikata TSL e klientit"

, "Initial Admin User"
: "Administratori Fillestar"

, "Initial admin login name"
: "Emri fillestar hyrës i administratorit"

, "Initial admin Password"
: "Fjalëkalimi fillestar i administratorit"

, "Password confirmation"
: "Konfirmim i fjalëkalimit"

, "Authentication provider"
: "Dhënësi i autentifikimit"

, "Try to split username"
: "Mundohu të ndash Emrin e përdoruesit"

, "Account canonical form"
: "Llogari e autorizuar nga"

, "Account domain name"
: ""

, "Account domain short name"
: "Emri i shkurtër i llogarisë domain"

, "Host"
: "Pritësi(Host)"

, "Login name"
: "Emri i Hyrjes"

, "Bind requires DN"
: "Bind kërkon DN"

, "Start TLS"
: "Nis TSL"

, "Base DN"
: "DN bazë"

, "Search filter"
: "Filtri i kërkimit"

, "Certificate validation"
: "Vertetimi i certifikates"

, "CA file"
: "Skedari CA"

, "CRL directory"
: "Dosja e CRL"

, "Accounts storage"
: "Vëndruajtja e Llogarive"

, "Default user group name"
: "Emri i paracaktuar i grupit të përdoruesve"

, "Default admin group name"
: "Emri i paracaktuar i grupit të administratorëve"

, "Login panel"
: "Paneli Hyrjes"

, "Reuse last username logged"
: "Ri-përdor emrin e përdoruesit të fundit "

, "Password Settings"
: "Konfigurimet e Fjalëkalimit"

, "User can change password"
: "Përdoruesi mund të ndryshojë fjalëkalimin"

, "Enable password policy"
: "Aktivizo politikën e fjalëkalimit"

, "Only ASCII"
: "Vetëm ASCII"

, "Minimum length"
: "Gjatësia minimale"

, "Minimum word chars"
: "minimumi i karaktereve në fjalë"

, "Minimum uppercase chars"
: "Minimumi i karaktereve të mëdha"

, "Minimum special chars"
: "Minimumi i karaktereve të vecanta"

, "Minimum numbers"
: "Minimumi i numrave"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: "Mos lejo një pjesë të emirt të përdoruesit në fjalëkalim"

, "Redirect Settings"
: "Ridrejto konfigurimet"

, "Redirect Url (redirect to login screen if empty)"
: "Ridrejto URL(ridrejto tek pamja e hyrjes nëse është bosh)"

, "Redirect Always (if No, only redirect after logout)"
: "Ridrejto gjithmonë (nëse Jo, ridrejto pas daljes)"

, "Redirect to referring site, if exists"
: "Ridrejto tek faqja referuese, nëse ekziton"

, "Password encoding"
: "Kodim i Fjalëkalimit"

, "des"
: "des"

, "crypt"
: ""

, "blowfish_crypt"
: "blowfish_crypt"

, "md5_crypt"
: "md5_crypt"

, "ext_crypt"
: "ext_crypt"

, "md5"
: "md5"

, "smd5"
: "smd5"

, "sha"
: "sha"

, "ssha"
: "ssha"

, "ntpassword"
: "ntpassword"

, "plain"
: "i thjeshtë"

, "User DN"
: "DN e Përdoruesit"

, "User Filter"
: "Filtri i Përdoruesit"

, "User Search Scope"
: "Qëllimi i kërkimit të përdoruesit"

, "Groups DN"
: "DN e Grupeve"

, "Group Filter"
: "Filtri i Grupeve"

, "Group Search Scope"
: "Qëllimi i Kerkimit të Grupeve"

, "Use Rfc 2307 bis"
: "Përdor Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: "Ruaj atributet RFC 2307"

, "Min User Id"
: "ID minimale e Përdoruesit"

, "Max User Id"
: "ID maksimale e Përdoruesit"

, "Min Group Id"
: "ID minimale e Grupit"

, "Max Group Id"
: "ID maksimale e Grupit"

, "Group UUID Attribute name"
: "Emiri i atributit UUID të Grupit"

, "User UUID Attribute name"
: "Emri i atrubutit UUID të përdoruesit"

, "Readonly access"
: "E drejtë vetëm për të lexuar"

, "Save config and install"
: "Ruaj konfigurimin dhe instalo"

, "Passwords don't match"
: "Fajlëkalimet nuk përkojnë"

, "Should not be empty"
: "Nuk duhet të jetë bosh"

, "Setup"
: ""

, "Application, Applications"
: [
  "Aplikacion"
 ,"Aplikacione"

]
, "Name"
: "Emër"

, "Enabled"
: "Aktivizuar"

, "Order"
: "Porosi"

, "Installed Version"
: "Versioni i Instaluar"

, "Available Version"
: "Version i disponueshëm"

, "Status"
: "Status"

, "Depends on"
: "Varet nga"

, "Uninstall application"
: "Ç'instalo aplikacionin"

, "Update application"
: "Përditëso aplikacionin"

, "Go to {0} login"
: "Shko tek hyrja {0}"

, "uninstall"
: "Ç'instalo"

, "Do you really want to uninstall the application(s)?"
: "Doni vërtet të ç'instaloni aplikacionin(et)?"

, "This may take a while"
: "Kjo mund të dojë pak kohë"

, "Dependency Violation"
: "Shkelje të Varësive"

, "CLI Required"
: ""

, "Application"
: "Aplikacion"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Setup/js/Setup-lang-sq-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "I have read the license agreement and accept it"
: "Unë e kam lexuar marrveshjen e licensave dhe e kam pranuar atë"

, "License Agreement"
: "Marveshje Licensash"

, "I have read the privacy agreement and accept it"
: "Unë e kam lexuar marrveshjen e fshehtësive dhe e kam pranuar atë"

, "Privacy Agreement"
: "Marrveshje e Fshehtësive"

, "Accept Terms and Conditions"
: "Prano Kushtet dhe Konditat"

, "Backend"
: "Fundori"

, "Standard IMAP"
: "IMAP standart"

, "Standard SMTP"
: "SMPT standarte"

, "Imap"
: "Imap"

, "Hostname"
: "Emri i Pritësit(Host)"

, "Username"
: "Emri Përdoruesit"

, "Password"
: "Fjalëkalimi"

, "Port"
: "Porta"

, "Secure Connection"
: "Lidhje e sigurtë"

, "None"
: "Asnjë"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Përdor llogarinë e sistemit"

, "No"
: "Jo"

, "Yes"
: "Po"

, "Append domain to login name"
: "Bashkangjit domain me emrin e hyrjes"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Administrator Cyrus"

, "Cyrus Admin Password"
: "Fjalëkalimi i administratorit Cyrus"

, "Use proxy auth"
: "Përdor autentifikim proxy"

, "Smtp"
: "Smtp"

, "Authentication"
: "Autentifikim"

, "Login"
: "Hyrje"

, "Plain"
: "E thjeshtë"

, "Primary Domain"
: "Domain parësor"

, "Secondary Domains (comma separated)"
: "Domain dytësor (e ndare me presje)"

, "Notifications service address"
: "Adresa e shërbimit të njoftimeve"

, "Notification Username"
: "Emër përdoruesi i njoftuesit"

, "Notification Password"
: "Fjalëkalimi i njoftuesit"

, "Notifications local client (hostname or IP address)"
: "Klienti lokal i njoftimeve ( emri pritesit(host) ose adresa IP)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "Emri Pritësit(host) MySql"

, "MySql Database"
: "Databaza MySql"

, "MySql User"
: "Përdoruesi MySql"

, "MySql Password"
: "Fjalëkalimi MySql"

, "MySql Port"
: "Porta MySql"

, "User or UID"
: "Përdorues ose UID"

, "Group or GID"
: "Grup ose GID"

, "Home Template"
: "Shablloni kryesor"

, "Password Scheme"
: "Skema e Fjalëkalimit"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLAIN"

, "Terms and Conditions"
: "Kushtet dhe Konditat"

, "Setup Checks"
: "Kontrolle Konfigurimi"

, "Config Manager"
: "Menaxhuesi i Konfigurimeve"

, "Authentication/Accounts"
: "Autentifikimi/Llogaritë"

, "Email"
: "E-Postë"

, "Application Manager"
: "Menaxheri i Aplikacioneve"

, "Setup"
: ""

, "Name"
: "Emër"

, "Enabled"
: "Aktivizuar"

, "Order"
: "Porosi"

, "Installed Version"
: "Versioni i Instaluar"

, "Available Version"
: "Version i disponueshëm"

, "Status"
: "Status"

, "Depends on"
: "Varet nga"

, "Install application"
: "Instalo aplikacionin"

, "Uninstall application"
: "Ç'instalo aplikacionin"

, "Update application"
: "Përditëso aplikacionin"

, "Go to {0} login"
: "Shko tek hyrja {0}"

, "uninstall"
: "Ç'instalo"

, "Do you really want to uninstall the application(s)?"
: "Doni vërtet të ç'instaloni aplikacionin(et)?"

, "This may take a while"
: "Kjo mund të dojë pak kohë"

, "Dependency Violation"
: "Shkelje të Varësive"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "Fshij të gjithë Grupet dhe Përdoruesit"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Ndryshimi nga SQL në LDAP do të fshijë të gjitha Logaritë e Përdoruesëve, Grupet, dhe RoletDoni vërtetë të ndryshoni arkivën fundore të përdoruesve në LDAP?"

, "TLS client certificate"
: "Certifikata TSL e klientit"

, "Initial Admin User"
: "Administratori Fillestar"

, "Initial admin login name"
: "Emri fillestar hyrës i administratorit"

, "Initial admin Password"
: "Fjalëkalimi fillestar i administratorit"

, "Password confirmation"
: "Konfirmim i fjalëkalimit"

, "Authentication provider"
: "Dhënësi i autentifikimit"

, "Try to split username"
: "Mundohu të ndash Emrin e përdoruesit"

, "Account canonical form"
: "Llogari e autorizuar nga"

, "Account domain name"
: ""

, "Account domain short name"
: "Emri i shkurtër i llogarisë domain"

, "Host"
: "Pritësi(Host)"

, "Login name"
: "Emri i Hyrjes"

, "Bind requires DN"
: "Bind kërkon DN"

, "Start TLS"
: "Nis TSL"

, "Base DN"
: "DN bazë"

, "Search filter"
: "Filtri i kërkimit"

, "Certificate validation"
: "Vertetimi i certifikates"

, "CA file"
: "Skedari CA"

, "CRL directory"
: "Dosja e CRL"

, "Accounts storage"
: "Vëndruajtja e Llogarive"

, "Default user group name"
: "Emri i paracaktuar i grupit të përdoruesve"

, "Default admin group name"
: "Emri i paracaktuar i grupit të administratorëve"

, "Login panel"
: "Paneli Hyrjes"

, "Reuse last username logged"
: "Ri-përdor emrin e përdoruesit të fundit "

, "Password Settings"
: "Konfigurimet e Fjalëkalimit"

, "User can change password"
: "Përdoruesi mund të ndryshojë fjalëkalimin"

, "Enable password policy"
: "Aktivizo politikën e fjalëkalimit"

, "Only ASCII"
: "Vetëm ASCII"

, "Minimum length"
: "Gjatësia minimale"

, "Minimum word chars"
: "minimumi i karaktereve në fjalë"

, "Minimum uppercase chars"
: "Minimumi i karaktereve të mëdha"

, "Minimum special chars"
: "Minimumi i karaktereve të vecanta"

, "Minimum numbers"
: "Minimumi i numrave"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: "Mos lejo një pjesë të emirt të përdoruesit në fjalëkalim"

, "Redirect Settings"
: "Ridrejto konfigurimet"

, "Redirect Url (redirect to login screen if empty)"
: "Ridrejto URL(ridrejto tek pamja e hyrjes nëse është bosh)"

, "Redirect Always (if No, only redirect after logout)"
: "Ridrejto gjithmonë (nëse Jo, ridrejto pas daljes)"

, "Redirect to referring site, if exists"
: "Ridrejto tek faqja referuese, nëse ekziton"

, "Password encoding"
: "Kodim i Fjalëkalimit"

, "des"
: "des"

, "crypt"
: ""

, "blowfish_crypt"
: "blowfish_crypt"

, "md5_crypt"
: "md5_crypt"

, "ext_crypt"
: "ext_crypt"

, "md5"
: "md5"

, "smd5"
: "smd5"

, "sha"
: "sha"

, "ssha"
: "ssha"

, "ntpassword"
: "ntpassword"

, "plain"
: "i thjeshtë"

, "User DN"
: "DN e Përdoruesit"

, "User Filter"
: "Filtri i Përdoruesit"

, "User Search Scope"
: "Qëllimi i kërkimit të përdoruesit"

, "Groups DN"
: "DN e Grupeve"

, "Group Filter"
: "Filtri i Grupeve"

, "Group Search Scope"
: "Qëllimi i Kerkimit të Grupeve"

, "Use Rfc 2307 bis"
: "Përdor Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: "Ruaj atributet RFC 2307"

, "Min User Id"
: "ID minimale e Përdoruesit"

, "Max User Id"
: "ID maksimale e Përdoruesit"

, "Min Group Id"
: "ID minimale e Grupit"

, "Max Group Id"
: "ID maksimale e Grupit"

, "Group UUID Attribute name"
: "Emiri i atributit UUID të Grupit"

, "User UUID Attribute name"
: "Emri i atrubutit UUID të përdoruesit"

, "Readonly access"
: "E drejtë vetëm për të lexuar"

, "Save config and install"
: "Ruaj konfigurimin dhe instalo"

, "Save config"
: "Ruaj konfigurimin"

, "Passwords don't match"
: "Fajlëkalimet nuk përkojnë"

, "Should not be empty"
: "Nuk duhet të jetë bosh"

, "Performing Environment Checks..."
: "Duke kryer kontrollet e ambientit..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "Nuk u gjet ndonje {0}. Ju lutem provoni të ndryshoni kërkesat e fitrave tuaj, mundësite e shfaqesose {1} ku kërkoni"

, "Check"
: "Kontrollo"

, "Result"
: "Rezultati"

, "Error"
: "Gabim"

, "Run setup tests"
: "Kryej teste konfigurimi"

, "Ignore setup tests"
: "Injoro testet e konfigurimit"

, "Application, Applications"
: [
  "Aplikacion"
 ,"Aplikacione"

]
, "File"
: "Skedar"

, "Setup Authentication"
: "Autentifikimi i Konfigurimit"

, "Database"
: "Databaza"

, "User"
: "Përdorues"

, "Prefix"
: "Prefiks"

, "Logging"
: "Hyrje"

, "Filename"
: "Emri i Skedarit"

, "Priority"
: "Prioriteti"

, "Caching"
: "Duke Fshehur(caching)"

, "Lifetime (seconds)"
: "Kohzgjatja (seconda)"

, "Path"
: "Rruga"

, "Queue"
: "Rradhë"

, "Session"
: "Seksion"

, "Temporary files"
: "Skedarë të përkohshëm"

, "Temporary Files Path"
: "Rrugë e përkohshme e skedarëve"

, "Filestore directory"
: "Vendruajtja e skedarëve"

, "Filestore Path"
: "Rruga e vendruajtjes së skedarëve"

, "Addressbook Map panel"
: "Paneli i hartës së Bllokut të adresave"

, "Map panel"
: "Paneli hartës"

, "disabled"
: "ç'aktivizuar"

, "enabled"
: "aktivizuar"

, "Config file is not writable"
: "Skedari i konfigurimit nuk është i shkruajtshëm "

, "Download config file"
: "Shkarko skedarin e konfigurimit"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Application"
: "Aplikacion"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
